Package 'optimos.prime'

Title: Optimos Prime Helps Calculate Autoecological Data for Biological Species
Description: Calculates autoecological data (optima and tolerance ranges) of a biological species given an environmental matrix. The package calculates by weighted averaging, using the number of occurrences to adjust the tolerance assigned to each taxon to estimate optima and tolerance range in cases where taxa have unequal occurrences. See the detailed methodology by Birks et al. (1990) <doi:10.1098/rstb.1990.0062>, and a case example by Potapova and Charles (2003) <doi:10.1046/j.1365-2427.2003.01080.x>.
Authors: María Belén Sathicq [aut], María Mercedes Nicolosi Gelis [aut], Joaquín Cochero [cre]
Maintainer: Joaquín Cochero <[email protected]>
License: GNU General Public License
Version: 0.1.2
Built: 2026-05-20 09:19:33 UTC
Source: https://github.com/cran/optimos.prime

Help Index


Environmental Sample Data - Example 2

Description

This sample data is a partial dataset from Sathicq, María Belén. (2017). Empleo de descriptores fitoplanctónicos como biomonitores en la evaluación de la calidad del agua en la costa del río de la Plata (Franja Costera Sur). PhD thesis. http://hdl.handle.net/10915/58915

Usage

data(environmental_data_example_2)

Format

A data frame with 5 environmental variables for 19 samples

http://hdl.handle.net/10915/58915

References

Sathicq, María Belén. (2017). Empleo de descriptores fitoplanctónicos como biomonitores en la evaluación de la calidad del agua en la costa del río de la Plata (Franja Costera Sur). PhD thesis.


Environmental Sample Data

Description

This sample data is a partial dataset from Sathicq, María Belén. (2017). Empleo de descriptores fitoplanctónicos como biomonitores en la evaluación de la calidad del agua en la costa del río de la Plata (Franja Costera Sur). PhD thesis. http://hdl.handle.net/10915/58915

Usage

data(environmental_data)

Format

A data frame with 11 environmental variables for 50 samples

http://hdl.handle.net/10915/58915

References

Sathicq, María Belén. (2017). Empleo de descriptores fitoplanctónicos como biomonitores en la evaluación de la calidad del agua en la costa del río de la Plata (Franja Costera Sur). PhD thesis.


This function of Optimos Prime calculates optima and tolerance for a data frame of species and environmental factors

Description

You will need two data frames. If they are not specified as arguments, you will be prompted to import them from CSV format. The resulting data frame from the op_calculate() function will be a data frame of species (rows) and the optima and tolerance range (+ and -) of the environmental variables (columns)

  • Matrix 1: Species (rows) by Sampling sites (columns). First row needs to be the sampling sites names. First column needs to be the species' names. Values in cells therefore need to be the density of each species at each site.

  • Matrix 2: Environmental variables (rows) by Sampling sites (columns). First row needs to be the sampling sites names. First column needs to be the names of the environmental variables (i.e. physical-chemical parameters). Values in cells therefore need to be the value of each environmental variable at each site.

The calculations for optima and tolerance ranges is conducted according to the article by Potapova & Charles (2003):

  • Potapova, M., & Charles, D. F. (2003). Distribution of benthic diatoms in US rivers in relation to conductivity and ionic composition. Freshwater Biology, 48(8), 1311-1328.

Sample data is taken from:

  • Sathicq, María Belén. (2017). Empleo de descriptores fitoplanctónicos como biomonitores en la evaluación de la calidad del agua en la costa del río de la Plata (Franja Costera Sur). PhD thesis. http://hdl.handle.net/10915/58915

Usage

op_calculate(environmental_df, species_df, isRelAb = TRUE,
  islog10 = FALSE)

Arguments

environmental_df

The data frame with your environmental data. Variables as rows, Sites as columns

species_df

The data frame with your species densities. Species as rows, Sites as columns.

isRelAb

Boolean. If set to 'TRUE' it means that your species' data is the relative abundance of each species per site. If FALSE, it means that it the data corresponds to absolute densities. Default = TRUE

islog10

Boolean. If set to 'TRUE' it means that your environmental data is already transformed to log10. Default = FALSE

Examples

# EXAMPLE 1: Loads sample data where species are in relative abundance (percent)
data("environmental_data")
data("species_data")
# EXAMPLE 2: Loads sample data where species are in absolute densities
data("environmental_data_example2")
data("species_data_example2")
# Calculates the autoecological data
optimos.prime::op_calculate(environmental_df, species_df)

Optimos Prime calculates optima and tolerance for a matrix of species and environmental factors

Description

You will need two dataframes. If they are not specified as arguments, you will be prompted to import them from CSV format.

  • Matrix 1: Species (rows) by Sampling sites (columns). First row needs to be the sampling sites names. First column needs to be the species' names. Values in cells therefore need to be the density of each species at each site.

  • Matrix 2: Environmental variables (rows) by Sampling sites (columns). First row needs to be the sampling sites names. First column needs to be the names of the environmental variables (i.e. physical-chemical parameters). Values in cells therefore need to be the value of each environmental variable at each site.

Usage

op_lists(environmental_df, species_df, listOnly = 0)

Arguments

environmental_df

The dataframe with your environmental data. Variables as rows, Sites as columns

species_df

The dataframe with your species densities. Species as rows, Sites as columns.

listOnly

Which lists to return. If = 0, then returns all three lists combined (Sites, Species, Environmental). If = 1, it returns only lists of Sites. If = 2, it returns only list of Species. If = 3, it returns only list of Environmental parameters.

Details

This function (op_lists) generates three lists from your dataframes: a species list, an environmental factors list and a sample (or sampling sites) list


Optimos Prime calculates optima and tolerance for a matrix of species and environmental factors

Description

This function plots the specified variable in a caterpillar plot

Usage

op_plot(optimaDF, label)

Arguments

optimaDF

The dataframe resulting from the op_calculate() method.

label

(optional) The label for the X axis (usually the environmental variable's name)

Details

This function (op_plot) generates caterpillar plots for a specified environmental variable showing optima and tolerance ranges as calculated with the op_calculate() function


Optimos Prime: A package for calculating autoecological data (optima and tolerance range) for biological species

Description

The calculations for optima and tolerance ranges is conducted according to the article by Birks et al. (1990). A case study for this technique is shown in Potapova & Charles (2003):

  • Birks, H.J.B., Line J.M., Juggins S., Stevenson A.C., and Ter Braak C.J.F. (1990). Diatoms and pH reconstruction. Philosophical Transactions of the Royal Society B 327:263–278

  • Potapova, M., & Charles, D. F. (2003). Distribution of benthic diatoms in US rivers in relation to conductivity and ionic composition. Freshwater Biology, 48(8), 1311-1328.

Sample data is taken from:

  • Sathicq, Maria Belen. (2017). Empleo de descriptores fitoplanctonicos como biomonitores en la evaluacion de la calidad del agua en la costa del Rio de la Plata (Franja Costera Sur). PhD thesis. <http://hdl.handle.net/10915/58915>

Functions

op_calculate() op_lists() op_plot()


Species Sample Data - Example 2

Description

This sample data is a partial dataset from Sathicq, María Belén. (2017). Empleo de descriptores fitoplanctónicos como biomonitores en la evaluación de la calidad del agua en la costa del río de la Plata (Franja Costera Sur). PhD thesis. http://hdl.handle.net/10915/58915

Usage

data(species_data_example_2)

Format

A data frame with the density value for 36 species in 19 samples

http://hdl.handle.net/10915/58915

References

Sathicq, María Belén. (2017). Empleo de descriptores fitoplanctónicos como biomonitores en la evaluación de la calidad del agua en la costa del río de la Plata (Franja Costera Sur). PhD thesis. http://hdl.handle.net/10915/58915


Species Sample Data

Description

This sample data is a partial dataset from Sathicq, María Belén. (2017). Empleo de descriptores fitoplanctónicos como biomonitores en la evaluación de la calidad del agua en la costa del río de la Plata (Franja Costera Sur). PhD thesis. http://hdl.handle.net/10915/58915

Usage

data(species_data)

Format

A data frame with the relative abundance for 57 species in 50 samples

http://hdl.handle.net/10915/58915

References

Sathicq, María Belén. (2017). Empleo de descriptores fitoplanctónicos como biomonitores en la evaluación de la calidad del agua en la costa del río de la Plata (Franja Costera Sur). PhD thesis. http://hdl.handle.net/10915/58915